#!/usr/bin/perl
# This Perl script will read the /etc/default/fppath file 
# and the environmental variables PF*, FP* to locate
# the filePro programs and data files. It will print out 
# these values and the contents of the config file. 
#
# Brought to you by: Laura Brody
#                on: 01 July 2000
# filePro Developer's Journal, Volume 1 Number 3.
# Copyright 2000, Hudson Valley Computer Associates, Inc.
#             http://www.hvcomputer.com 
# This code is freely distributable as long as this comment
# and author's name is in it. Please send any enhancements
# or suggestions to laura@hvcomputer.com.
#
# It requires the files:
# English.pm 	(use less cryptic names of built-in variables),
# cwd.pm 	(current working directory).
# You may need to set PERLLIB to the location of these files.
use English;
use Cwd;

# grab the following environmental variables:  ABE, PF* and FP*
%fpenv = ();	# define a hash table to store the info
foreach $k (sort keys %ENV) # read in all env vars in alphbetical order
{   $v = $ENV{$k};
    if ($OSNAME eq "MSWin32")
    {	$k =~ tr/a-z/A-Z/; # force everything to upper case
    }
    $ARG = $k;
    # Note: Because FPxxx sorts before PFxxx, the PFxxx value will
    # override a matching FPxxx entry, which is the same behavior
    # as filePro.
    if ( m/^ABE$/ || m/^PF/ || m/^FP/ )
    {   $k =~ s/^FP/PF/;	# Convert FPxxx to PFxxx
	$fpenv{$k} = $v;
    }
}

# Read PFPROG, PFDATA, and PFDIR from the fppath file

# Decide the location of the fppath file
$PATHFILE = ($OSNAME eq "MSWin32") 
	? join "",substr(getcwd(),0,2), "/fppath"
	: "/etc/default/fppath";
if ( open (PATHFILE,"< $PATHFILE") )
{   @fppath = <PATHFILE>; # dump the contents into an array
    chomp(@fppath); # remove the newline characters.
    $fpenv{"PFPROG"} ||= $fppath[0]; #first line
    $fpenv{"PFDATA"} ||= $fppath[1]; #second line
    $fpenv{"PFDIR"}  ||= $fppath[2]; #third line
    close PATHFILE;
}

# Now that we know where the program and data files are located,
# we can read and display the contents of the config file.

# Note: PFCONFIG can override "$PFPROG/fp/lib/config"
$CONFIGFILE = $fpenv{"PFCONFIG"} || $fpenv{"PFPROG"}."/fp/lib/config";
if ( open (CONFIGFILE,"< $CONFIGFILE") )
{   while(<CONFIGFILE>)
    {	chomp;
	# skip the "Colors:" label, display everything else.
	if( ! /^Colors:/)
	{	($env,$value) = split(/=/,$ARG,2);
		$env =~ s/^\s+//;    # remove any leading spaces
		if ($OSNAME eq "MSWin32")
		{	$env =~ tr/a-z/A-Z/; # force everything to upper case
		}
 		$fpenv{$env} ||= $value;
	}
    }
    close $CONFIGFILE;
}

# For debugging purposes: display the results

print join "", "-" x 20, " contents of fpenv ", "-" x 20, "\n";
foreach $key (sort keys %fpenv)
{	print "$key=$fpenv{$key}\n";
}
print join "", "-" x 20, " contents of fpenv ", "-" x 20, "\n";
